# FEATS

A new python tool for performing the following downstream analysis on single cell RNA-seq datasets:

1. Clustering
2. Estimating the number of clusters
3. Outlier detection
4. Batch correction and integration of data from multiple experiments
